@@ -21,7 +21,7 @@ import os
 import os.path
 
 PACKAGE    = "sabayon"
-VERSION    = "0.18"
+VERSION    = "2.12.0"
 DATADIR    = "/gnome/head/INSTALL/share"
 SYSCONFDIR = "/gnome/head/INSTALL/etc"
 LIBEXECDIR = "/gnome/head/INSTALL/libexec"
@@ -30,16 +30,15 @@ SBINDIR    = "/gnome/head/INSTALL/sbin"
 GLADEDIR    = os.path.join (DATADIR, "sabayon", "glade")
 PROFILESDIR = os.path.join (SYSCONFDIR, "desktop-profiles")
 
-SESSION_TOOL_ARGV = [ os.path.join (LIBEXECDIR, "sabayon-session") ]
 MONITOR_TOOL_ARGV = [ os.path.join (LIBEXECDIR, "sabayon-monitor") ]
+SESSION_TOOL_ARGV = [ os.path.join (LIBEXECDIR, "sabayon-session") ]
 APPLY_TOOL_ARGV   = [ os.path.join (SBINDIR,    "sabayon-apply") ]
 
 # FIXME: this is too big a hammer
 CLOBBER_USER_PROCESSES_ARGV = [ "/usr/bin/pkill", "-u" ]
 
-# No. of seconds to wait after the session has started before
-# running the monitor tool
-ADMIN_TOOL_TIMEOUT = 3
+# No. of seconds to wait for USR1 from Xnest before giving up
+XNEST_USR1_TIMEOUT = 10
 
 #
 # This is the user which we run the prototype sessions
@@ -54,7 +53,7 @@ NOLOGIN_SHELL = "/sbin/nologin"
 SKEL_HOMEDIR  = "/etc/skel"
 
 XNEST_ARGV   = [ "/usr/X11R6/bin/Xnest", "-terminate", "-audit", "0", "-nolisten", "tcp" ]
-SESSION_ARGV = [ "/etc/X11/xdm/Xsession", "gnome" ]
+SESSION_ARGV = [ "/etc/X11/xdm/Xsession", "@gnome" ]
 USERMOD_ARGV = [ "/usr/sbin/usermod" ]
 
 PANEL_KEY_BASE = "/apps/panel"
@@ -73,25 +72,51 @@ PASSTHROUGH_ENVIRONMENT = [
     "LC_TIME",
     "LC_NUMERIC",
     "LC_MONETARY",
-    "LC_MESSAGES"
+    "LC_MESSAGES",
+    "METACITY_VERBOSE",
+    "METACITY_USE_LOGFILE"
 ]
 
 #
-# Files a directories which we don't want to see change
-# notifications for
+# Files which we don't want to see change notifications for
 #
 FILES_TO_IGNORE = [
-    ".xsession-errors",
+    ".ICEauthority*",
+    ".esd_auth",
+    ".fonts.cache-1*",
+    ".gconf.path.defaults",
+    ".gconf.path.defaults.new",
+    ".gconf.path.mandatory",
+    ".gconf.path.mandatory.new",
     ".gnome/gnome-vfs/.trash_entry_cache",
+    ".gnome2/share/cursor-fonts/fonts.dir",
     ".gnome2/share/fonts/fonts.dir",
-    ".gnome2/share/cursor-fonts/fonts.dir"
+    ".gtkrc-1.2-gnome2*",
+    ".recently-used",
+    ".xsession-errors"
 ]
 
+#
+# Directories which we don't want to see change notifications for
+# 
 DIRECTORIES_TO_IGNORE = [
-    ".metacity/sessions",
     ".gconf",
     ".gconf.xml.defaults",
     ".gconf.xml.mandatory",
     ".gconfd",
-    ".nautilus/metafiles"
+    ".gstreamer-0.8",
+    ".metacity/sessions",
+    ".nautilus/metafiles",
+    ".profile_cache",
+    ".thumbnails"
+]
+
+#
+# GConf keys which we don't want to see change notifications for
+#
+GCONF_KEYS_TO_IGNORE = [
+    "/apps/nautilus/preferences_version",
+    "/apps/nautilus/sound_state",
+    "/apps/panel/general/profiles_migrated"
+    "/desktop/gnome/peripherals/keyboard/kbd.sysbackup/*",
 ]
