@@ -40,7 +40,7 @@ def copy_tree (dst_base, src_base, dst_name, src_name = None, overwrite = False)
         src_name = dst_name
     
     try:
-        dprint ("Making dir %s" % os.path.join (dst_base, dst_name))
+        dprint ("Making dir %s", os.path.join (dst_base, dst_name))
         os.mkdir (os.path.join (dst_base, dst_name))
     except OSError, err:
         if err.errno != errno.EEXIST:
@@ -148,12 +148,12 @@ class ProfileStorage:
             return
 
         if not os.path.exists (self.path):
-            dprint ("Profile file '%s' doesn't exist" % self.path)
+            dprint ("Profile file '%s' doesn't exist", self.path)
             self.metadata = self.__create_empty_metadata_doc ()
             self.needs_saving = True
             return
 
-        dprint ("Reading metadata from '%s'" % self.path)
+        dprint ("Reading metadata from '%s'", self.path)
             
         try:
             self.zip = zipfile.ZipFile (self.path, "r")
@@ -426,7 +426,7 @@ class ProfileStorage:
         self.revisions_path = os.path.join (self.temp_path, "%revisions%")
         os.mkdir (self.revisions_path)
 
-        dprint ("Unpacking '%s' in '%s'" % (self.path, self.temp_path))
+        dprint ("Unpacking '%s' in '%s'", self.path, self.temp_path)
 
         if not self.zip:
             return
@@ -500,8 +500,8 @@ class ProfileStorage:
             try:
                 shutil.copyfile (self.path, new_path)
             except:
-                dprint ("Failed to copy profile from '%s' to '%s': %s" % \
-                        (self.path, new_path, sys.exc_info()[1]))
+                dprint ("Failed to copy profile from '%s' to '%s': %s",
+                        self.path, new_path, sys.exc_info()[1])
         
         retval = ProfileStorage (name)
         retval.clear_revisions ()
@@ -522,7 +522,7 @@ class ProfileStorage:
         @attributes: a varargs list of arbitrary key/value pairs
         (specific to @source) which should be saved.
         """
-        dprint ("Adding '%s' from %s:%s" % (path, source, src_dir))
+        dprint ("Adding '%s' from %s:%s", path, source, src_dir)
         
         self.__unpack ()
 
@@ -599,6 +599,59 @@ class ProfileStorage:
 
         self.needs_saving = True
         
+    def __get_item_type_and_revision (self, path, revision):
+        self.__unpack ()
+
+        if not revision:
+            profile_revision = self.__get_current_profile_revision ()
+            if not profile_revision:
+                raise ProfileStorageException (_("No current revision"))
+            
+            item = self.__get_profile_revision_item (profile_revision, path)
+            if not item:
+                raise ProfileStorageException (_("'%(path)s' does not exist in profile revision '%(profile_revision)s'"),
+                                                   path, profile_revision)
+
+            item_type     = item.prop ("type")
+            item_revision = item.prop ("revision")
+        else:
+            (item_type, item_revision) = revision.split (":")
+
+            if item_type == "profile":
+                item = self.__get_profile_revision_item (item_revision, path)
+                if not item:
+                    raise ProfileStorageException (_("'%(path)s' does not exist in profile revision '%(profile_revision)s'"),
+                                                   path, profile_revision)
+
+                item_type     = item.prop ("type")
+                item_revision = item.prop ("revision")
+
+        return (item_type,
+                item_revision,
+                self.__item_revision_is_current (path, item_type, item_revision))
+        
+    def get_extract_src_path (self, path, revision = None):
+        """Return the src path of a file or directory for extraction from the profile.
+
+        @path: the relative path of the file or directory to extract.
+        This is the same path used with ProfileStorage::add().
+        @revision: an (optional) revision identifier which specifies
+        the revision of the file or directory which should be extracted.
+        The revision identifier must have been returned from
+        ProfileStorage::get_revisions() and may be a profile or file
+        revision.
+        """
+        (item_type, item_revision, is_current) = self.__get_item_type_and_revision (path, revision)
+        
+        if is_current:
+            extract_src_path = os.path.join (self.temp_path, path)
+        else:
+            extract_src_path = os.path.join (self.revisions_path, path, item_revision)
+
+        dprint ("Extract src path for '%s', revision %s is '%s'", path, revision, extract_src_path)
+        
+        return os.path.normpath (extract_src_path)
+
     def extract (self, path, dst_dir, overwrite = False, revision = None):
         """Extract a file or directory from the profile.
 
@@ -613,58 +666,28 @@ class ProfileStorage:
         ProfileStorage::get_revisions() and may be a profile or file
         revision.
         """
-        dprint ("Extracting '%s' to '%s', revision %s" % (path, dst_dir, revision))
+        dprint ("Extracting '%s' to '%s', revision %s", path, dst_dir, revision)
         
-        self.__unpack ()
+        (item_type, item_revision, is_current) = self.__get_item_type_and_revision (path, revision)
 
-        if not revision:
-            profile_revision = self.__get_current_profile_revision ()
-            if not profile_revision:
-                raise ProfileStorageException (_("No current revision"))
-            
-            item = self.__get_profile_revision_item (profile_revision, path)
-            if not item:
-                raise ProfileStorageException (_("'%s' does not exist in profile revision '%s'"),
-                                               path, profile_revision)
-
-            item_type     = item.prop ("type")
-            item_revision = item.prop ("revision")
-        else:
-            (item_type, item_revision) = revision.split (":")
-
-            if item_type == "profile":
-                item = self.__get_profile_revision_item (item_revision, path)
-                if not item:
-                    raise ProfileStorageException (_("'%s' does not exist in profile revision '%s'"),
-                                                   path, profile_revision)
-                    return
-
-                item_type     = item.prop ("type")
-                item_revision = item.prop ("revision")
-
-        if self.__item_revision_is_current (path, item_type, item_revision):
-            if item_type == "directory":
+        if item_type == "directory":
+            if is_current:
                 copy_tree (dst_dir, self.temp_path, path, None, overwrite)
             else:
-                dst_path = os.path.join (dst_dir, path)
-                if overwrite or not os.path.exists (dst_path):
-                    dirname = os.path.dirname (dst_path)
-                    if not os.path.exists (dirname):
-                        os.makedirs (dirname)
-                    shutil.copy2 (os.path.join (self.temp_path, path), dst_path)
-        else:
-            if item_type == "directory":
                 copy_tree (dst_dir,
                            os.path.join (self.revisions_path, path),
                            path,
                            item_revision,
                            overwrite)
-            else:
-                dst_path = os.path.join (dst_dir, path)
-                if overwrite or not os.path.exists (dst_path):
-                    dirname = os.path.dirname (dst_path)
-                    if not os.path.exists (dirname):
-                        os.makedirs (dirname)
+        else:
+            dst_path = os.path.join (dst_dir, path)
+            if overwrite or not os.path.exists (dst_path):
+                dirname = os.path.dirname (dst_path)
+                if not os.path.exists (dirname):
+                    os.makedirs (dirname)
+                if is_current:
+                    shutil.copy2 (os.path.join (self.temp_path, path), dst_path)
+                else:
                     shutil.copy2 (os.path.join (self.revisions_path, path, item_revision), dst_path)
 
     def list (self, source = None, profile_revision = None):
@@ -723,17 +746,17 @@ class ProfileStorage:
             elif item_type == "directory":
                 revision_node = self.__get_directory_revision_node (item_path, item_revision)
             else:
-                dprint ("Unknown item type '%s' for path '%s' in revision '%s'" %
-                        (item_type, item_path, item_revision))
+                dprint ("Unknown item type '%s' for path '%s' in revision '%s'",
+                        item_type, item_path, item_revision)
                 continue
 
             if not revision_node:
-                dprint ("No revision '%s' for %s '%s" % (item_revision, item_type, item_path))
+                dprint ("No revision '%s' for %s '%s", item_revision, item_type, item_path)
                 continue
 
             item_source = self.__get_revision_source (revision_node)
             if not item_source:
-                dprint ("No source associated with item '%s'" % item_path)
+                dprint ("No source associated with item '%s'", item_path)
                 continue
 
             if source and source != item_source:
@@ -753,7 +776,7 @@ class ProfileStorage:
                                            (self.name))
         self.__read_metadata ()
         if not self.needs_saving:
-            dprint ("No changes to profile '%s' need saving" % self.name)
+            dprint ("No changes to profile '%s' need saving", self.name)
             return
 
         def failsafe_rename (src, dst):
@@ -768,7 +791,7 @@ class ProfileStorage:
         else:
             backup = None
         
-        dprint ("Writing contents of profile to '%s'" % self.path)
+        dprint ("Writing contents of profile to '%s'", self.path)
         
         try:
             save_zip = zipfile.ZipFile (self.path, "w")
